@@ -89,7 +89,7 @@ class AudioField(FileField):
             logger.error(error_msg)
             raise forms.ValidationError(error_msg)
 
-        convert_to = int(request.POST["convert_type"])
+        convert_to = request and int(request.POST["convert_type"])
         ext = ext.split('.')[1]
         audio_type = CONVERT_TYPE_CHK[convert_to]
         error_msg = _("not allowed : file format conversion is not allowed for same audio type (except Wav)")
@@ -132,7 +132,7 @@ class AudioField(FileField):
             logger.debug("convert MP3 to WAV - channel %s freq: %s" % (str(channel_no), str(freq_value)))
 
             #prepare Sox parameters for Channels convertion
-            conv_channel = "-s -c %s" % str(channel_no) if channel_no > 0 else ''
+            conv_channel = "-e signed-integer -c %s" % str(channel_no) if channel_no > 0 else ''
 
             #prepare Sox parameters for Frequency convertion
             conv_freq = "-r %s" % str(freq_value) if freq_value > 0 else ''
@@ -205,7 +205,8 @@ class AudioField(FileField):
         if ext == 'ogg' and CONVERT_TYPE_CHK[convert_type] == 'wav':
             logger.debug('OGG to WAV')
             #conv = "sox %s %s.wav" % (filename, splitted_filename)
-            conv = "ffmpeg -i %s %s.wav" % (filename, splitted_filename)
+            #conv = "ffmpeg -i %s %s.wav" % (filename, splitted_filename)
+            conv = "avconv -i %s -map_metadata 0:s:0 %s.wav" % (filename, splitted_filename)
             result = audio_convert_task.delay(conv)
             logger.debug("command :> %s" % conv)
 
